@@ -284,7 +284,7 @@ hierarchicalTesting <- function(indRoot, hierMat, group, grouplm, X, y, test = p
 #' @examples 
 #' set.seed(42)
 #' X = simuBlockGaussian(50,12,5,0.7)
-#' y = drop(X[,c(2,7,12)]%*%c(2,2,-2)+rnorm(50,0,0.5))
+#' y = X[,c(2,7,12)]%*%c(2,2,-2) + rnorm(50,0,0.5)
 #' res = MLGL(X,y)
 #' test = hierarchicalFWER(X, y, res$group[[20]], res$var[[20]])
 #' 
@@ -362,7 +362,7 @@ hierarchicalFWER <- function(X, y, group, var, test = partialFtest, Shaffer = FA
 #' @examples 
 #' set.seed(42)
 #' X = simuBlockGaussian(50,12,5,0.7)
-#' y = drop(X[,c(2,7,12)]%*%c(2,2,-2)+rnorm(50,0,0.5))
+#' y = X[,c(2,7,12)]%*%c(2,2,-2) + rnorm(50,0,0.5)
 #' res = MLGL(X,y)
 #' test = hierarchicalFWER(X, y, res$group[[20]], res$var[[20]])
 #' sel = selFWER (test, alpha = 0.05)
@@ -477,7 +477,7 @@ selFWER <- function(out, alpha = 0.05)
     stop("alpha must be a real between 0 and 1.")
   if((alpha <=0) || (alpha>1))
     stop("alpha must be a real between 0 and 1.")
-  
+ 
   # hierMatrix
   if(!is.matrix(hierMatrix)) 
     stop("hierMatrix has to be a matrix.")
@@ -485,14 +485,16 @@ selFWER <- function(out, alpha = 0.05)
     stop("Missing values in hierMatrix not allowed.")
   if(!is.logical(hierMatrix))
     stop("hierMatrix has to be a matrix of boolean.")
-  
+
   # adjPvalues
+  print(adjPvalues)
   if(!is.numeric(adjPvalues))
     stop("adjPvalues has to be a vector of real between 0 and 1.")
+
   # if(any(is.na(adjPvalues))) 
   #   stop("Missing values in adjPvalues not allowed.")
-  if(any((adjPvalues[!is.na(adjPvalues)] <= 0) || (adjPvalues[!is.na(adjPvalues)]  > 1)))
+  if(any(adjPvalues[!is.na(adjPvalues)] <= 0) || any(adjPvalues[!is.na(adjPvalues)]  > 1))
     stop("adjPvalues has to be a vector of real between 0 and 1.")
-  
+
   invisible(return(NULL))
 }
